==> arv_2.4.0-24.tar.gz: arv-24/web/static/js/lang-fr.js <==
Ext.i18n = {
    loading: 'Chargement ...',
    apply: 'Appliquer',
    ready: 'Prêt',

    // add/remove button
    ok: "OK",
    add: "Ajouter",
    remove: "Supprimer",
    modify: "Modifier",
    none_add_first: "Aucun, ajouter d'abord",

    //ok message
    message: 'Message',

    // error message
    error_select_connect: "Sélectionner d'abord un lien sécurisé",
    error_select_node1: "Sélectionner d'abord un serveur RVP 1",
    error_select_node2: "Sélectionner d'abord un serveur RVP 2",
    error_select_cred: "Sélectionner d'abord un certificat",
    error_select_tmplconnect: "Sélectionner d'abord un modèle de lien sécurisé",
    error_select_tmplnode: "Sélectionner d'abord un modèle de serveur RVP",
    error_select_tmpledge: "Sélectionner d'abord un modèle de tunnel",
    error_select_node: "Sélectionner d'abord un serveur RVP",
    error_select_etab: "Sélectionner d'abord un établissement",
    error_select_extrip: "Sélectionner d'abord une extrémité",
    error_select_edge: "Sélectionner d'abord un tunnel",
    error_title: 'Erreur',
    field_empty: 'Le champ ne doit pas être vide',
    row_not_selected: "Sélectionner d'abord un item",
    confirm_delete_title: 'Confirmer',
    confirm_delete: 'Êtes-vous sûr de vouloir supprimer cet item ?',
    json_error: 'Message de retour inattendu',
    observable_http_error: 'Erreur HTTP',
    url_not_found: 'Impossible de trouver la ressource ',

    // login window
    login_title: 'Authentification',
    login_user: 'Utilisateur',
    login_password: 'Mot de passe',
    login: 'Connexion',

    // tmpl_node
    add_tmpl_node_title: 'Ajouter un nouveau modèle de serveur RVP',
    add_tmpl_node: 'Nouveau nom :',

    // tmpl_vertex
    tmplvertex_label: 'Nom du modèle du réseau local pour',
    // window
    win_addtmpl_connect_title: 'Ajouter un nouveau modèle de lien sécurisé',
    win_addtmpl_edge_title: 'Ajouter un nouveau modèle de tunnel',
    tmpl_connect_name: 'Nom ',
    save: 'Créer',
    cancel: 'Annuler',
    exit: 'Fermer',
    connect_window: 'Liens sécurisés',
    del_choice_button: 'Suppr.',

	// Connect
	add_connect: 'Ajouter un lien sécurisé',

    // wizard
    previous: 'Précédent',
    next: 'Suivant',

    node: "Nom ",
    nodes: "Serveurs RVP",
    node1: "Serveur RVP 1",
    tmplnode: "Modèle de serveur RVP",
    tmplnode1: "Modèle de serveur RVP 1",
    tmplnode2: "Modèle de serveur RVP 2",
    node2: "Serveur RVP 2",
    template: "Modèles",
    credential: 'Certificat',
    edge: "Tunnel",
    edge_name: "Nom",
    view: "Tunnels",
    name: "Nom",
    errortitle: "Erreur",
    tmpl_connect: "Modèle de lien sécurisé",
    tmplvertex_name: "Nom ",
    tmplvertex1: "Modèle de réseau local 1",
    tmplvertex2: "Modèle de réseau local 2",
    tmplvertex_mimetype: "Type",
    tmplvertex_ip1: 'IP / Réseau',
    tmplvertex_ip2: 'IP / Masque',
    tmpledges: "Modèle de tunnel",
    addtmpledge_name: "Nom ",
    // add_node1
    addnode1_select_node_label: "Sélectionner un type de serveur RVP ...",
    addnode1_tmplnode: "Sélectionner un modèle de serveur RVP",
    addnode_name: "Nom ",
    uai: "UAI ",
    addnode1_title: 'Ajouter un nouveau serveur RVP',
    modify_node1_title: 'Modifier le serveur RVP',
    addextremity_title: 'Ajouter une nouvelle IP',
    modextremity_title: 'Modifier',
    addextremity_pub_ip: 'IP publique',
    addextremity_priv_ip: 'IP privée',
    external_ip: 'IP externe',
    send_db: 'Renvoyer sur Zéphir',
    sync_zephir: 'Zéphir infos serveur',
    addnode1_zephir: "Importation Zéphir",
    addnode1_manually: "Création manuelle",
    reload_tmplvertex: 'Recharger valeurs du modèle',

    // zephir
    zephir: 'Zéphir',
    zephir_etab_libelle: 'Nom ',
    zephir_etab_uai: 'UAI ',
    id_zephir: 'Identifiant Zéphir',
    eole_version: 'Version Eole',

    // add_node2
    addnode2_title: 'Ajouter un lien sécurisé vers',
    addnode2_tmplconnect: 'Choisir un modèle de lien sécurisé',
    addnode2_node: 'Choisir un serveur RVP',
    addnode2_choice_button: 'Ajouter',
    modnode2_choice_button: 'Modifier',
    addnode2_cred: 'Certificat',
    addnode2_extr: 'IP',
    addnode2_ask: 'Veuillez indiquer un nom de certificat',
    addnode2_ask_title: 'Nom ',
    extrip_title: 'IP externe',
    extrip_header: 'IP',
    //tmplvertex
    tmplvertex_title: 'Ajouter un réseau local',

    activate: '',
    // credentials
    cred_title: 'Certificats',
    addcred_title: 'Ajouter un nouveau certificat',
    modcred_title: 'Remplacer certificat',
    cred: 'Certificats',
    cred_header: 'Certificats',
    ca: 'CA',
    related_node: 'Serveur RVP associé',
    exp_date_title: "Date d'expiration",
    delta: 'Expire dans (j)',
    addcred_private_key: 'Clef privée',
    addcred_public_key: 'Certificat',
    addcred_passwd: 'Passphrase',
    addcred_name: 'Nom ',
    generated_new_cred: 'Générer un nouveau certificat',
    imported_old_cred: 'Importer un certificat',
    cred_request: 'Générer une requête de certificat pour une CA',
    autosign_cred: 'Certificat auto-signé',
    passwd: 'Choisir un mot de passe',
    passwd2: 'Confirmer le mot de passe',
    unmatched_passwd: 'Les mots de passe sont différents',
    //
    selectfile_upload: 'Sélectionner un fichier',
    selectcredential_label: 'Sélectionner un certificat pour ',

    certif_state: 'État',

    //tmplconnect
    addtmpl_connect_credauth: 'Sélectionner une autorité de certification',
    addtmpl_connect_name: 'Nom ',
    //vertex
    vertex_added: 'Réseau local ajouté',
    addvertex_name: 'Nom ',
    vertex_mimetype: 'Type',
    vertex_mimetype_ip: 'IP',
    vertex_mimetype_network: 'Réseau',
    vertex_mimetype_range: 'Plage',
    addvertex_ip_ip1: 'Adresse IP',
    addvertex_range_ip1: 'Adresse IP de début',
    addvertex_range_ip2: 'Adresse IP de fin',
    addvertex_network_ip1: 'Adresse réseau',
    addvertex_network_ip2: 'Adresse de masque',
    vertex_zephir_module: 'Module Zéphir',


    error_get_tmplnode: "Ne peut sélectionner d'établissement avec un type 'établissement'",

}

Ext.i18n.python = {
    'Node modified': 'Serveur RVP modifié',
    'TmplConnect added': 'Modèle de lien sécurisé ajouté',
    'TmplNode added': 'Modèle de serveur RVP ajouté',
    'Node deleted': 'Serveur RVP supprimé',
    'Edge deleted': 'Tunnel supprimé',
    'Edge and connect deleted': 'Tunnel et lien sécurisé supprimés',
    'Node is already used by a Connect, you cannot delete it': 'Serveur RVP déjà utilisé par un lien sécurisé, ne peut être supprimé',
    'Name should be unique': 'Le nom doit être unique',
    'Public IP should be unique': "L'adresse IP publique doit être unique",
    'error while saving database': "Erreur à l'enregistrement de la base de donnée",
    'Wrong node for this TmplVertex': 'Mauvais serveur RVP pour ce modèle de réseau local',
    'TmplEdge already exists': 'Ce modèle de tunnel existe déjà',
    'error in add_node: serveur name already in database': 'Le nom du serveur doit être unique',
    'No available connect': 'Pas de lien sécurisé dans la base',
    'Credential imported': 'Certificat importé',
    'Unable to decrypt private key, check password': 'Impossible de déchiffrer la clé privée, vérifier passphrase',
    'This TmplEdge is already used, cannot modify tmpl_vertex': 'Ce modèle de tunnel est déjà utilisé, ne peut modifier son modèle de réseau local',
    'Please enter a valid IP address (a.b.c.d)': 'Veuillez entrer une IP valide (a.b.c.d)',
    'Extremity is already used by a Connect, you cannot delete it': 'IP externe déjà utilisée dans un lien sécurisé, ne peut être supprimée',
    'Credential is already used by a Connect, you cannot delete it': 'Certificat utilisé dans un lien sécurisé, ne peut être supprimé',
    'Extemity deleted': 'IP externe supprimée',
    "CA does not exists in database, Can't add certificate": "La CA n'existe pas dans la base, ne peut ajouter le certificat",
    "TmplVertex is already used by a TmplEdge, you cannot delete it": "Ce modèle de réseau local est déjà utilisé par un modèle de tunnel, ne peut être supprimé",
    "New credential is issued with another CA than old one's": "Le nouveau certificat est créé à partir d'une autre CA que l'ancien",
    "Credential and private_key doesn't match": "Le certificat et la clef privée ne correspondent pas",
    "Error: unable to find VPN archive": "Erreur : impossible de trouver l'archive RVP",
    "Resended": "Archive envoyée",
    "Database created": "Bases de données créées",
    "Database created - !!! HighAvail synchro : remote node unreachable !!!": "Bases de données créées - !!! Synchronisation haute disponibilité : noeud distant injoignable !!!",
    "Configuration created": "Configurations strongSwan générées",
    "Configuration created - !!! HighAvail synchro : remote node unreachable !!!": "Configurations strongSwan générées - !!! Synchronisation haute disponibilité : noeud distant injoignable !!!",
    "Expiration date": "Date d'expiration",
    "TmplConnect is already used by a Connect, you cannot delete it": "Le modèle de lien est utilisé, suppression impossible",
    "Range network not supported": "Réseau de type Range non supporté",
    "Can't suppress edge template used by connect !!!": "Impossible de supprimer un modèle de tunnel utilisé par un lien sécurisé !!!",
}

==> arv_2.6.0-24.tar.gz: arv-24/web/static/js/lang-fr.js <==
Ext.i18n = {
    loading: 'Chargement ...',
    apply: 'Appliquer',
    ready: 'Prêt',

    // add/remove button
    ok: "OK",
    add: "Ajouter",
    remove: "Supprimer",
    modify: "Modifier",
    none_add_first: "Aucun, ajouter d'abord",

    //ok message
    message: 'Message',

    // error message
    error_select_connect: "Sélectionner d'abord un lien sécurisé",
    error_select_node1: "Sélectionner d'abord un serveur RVP 1",
    error_select_node2: "Sélectionner d'abord un serveur RVP 2",
    error_select_cred: "Sélectionner d'abord un certificat",
    error_select_tmplconnect: "Sélectionner d'abord un modèle de lien sécurisé",
    error_select_tmplnode: "Sélectionner d'abord un modèle de serveur RVP",
    error_select_tmpledge: "Sélectionner d'abord un modèle de tunnel",
    error_select_tmplvertex: "Sélectionner d'abord un modèle de réseau",
    error_select_node: "Sélectionner d'abord un serveur RVP",
    error_select_etab: "Sélectionner d'abord un établissement",
    error_select_extrip: "Sélectionner d'abord une extrémité",
    error_select_edge: "Sélectionner d'abord un tunnel",
    error_title: 'Erreur',
    field_empty: 'Le champ ne doit pas être vide',
    row_not_selected: "Sélectionner d'abord un item",
    confirm_delete_title: 'Confirmer',
    confirm_delete: 'Êtes-vous sûr de vouloir supprimer cet item ?',
    json_error: 'Message de retour inattendu',
    observable_http_error: 'Erreur HTTP',
    url_not_found: 'Impossible de trouver la ressource ',

    // login window
    login_title: 'Authentification',
    login_user: 'Utilisateur',
    login_password: 'Mot de passe',
    login: 'Connexion',

    // tmpl_node
    add_tmpl_node_title: 'Ajouter un nouveau modèle de serveur RVP',
    add_tmpl_node: 'Nouveau nom :',

    // tmpl_vertex
    tmplvertex_label: 'Nom du modèle du réseau local pour',
    // window
    win_addtmpl_connect_title: 'Ajouter un nouveau modèle de lien sécurisé',
    win_addtmpl_edge_title: 'Ajouter un nouveau modèle de tunnel',
    tmpl_connect_name: 'Nom ',
    save: 'Créer',
    cancel: 'Annuler',
    exit: 'Fermer',
    connect_window: 'Liens sécurisés',
    del_choice_button: 'Suppr.',

	// Connect
	add_connect: 'Ajouter un lien sécurisé',

    // wizard
    previous: 'Précédent',
    next: 'Suivant',

    node: "Nom ",
    nodes: "Serveurs RVP",
    node1: "Serveur RVP 1",
    tmplnode: "Modèle de serveur RVP",
    tmplnode1: "Modèle de serveur RVP 1",
    tmplnode2: "Modèle de serveur RVP 2",
    node2: "Serveur RVP 2",
    template: "Modèles",
    credential: 'Certificat',
    edge: "Tunnel",
    edge_name: "Nom",
    view: "Tunnels",
    name: "Nom",
    errortitle: "Erreur",
    tmpl_connect: "Modèle de lien sécurisé",
    tmplvertex_name: "Nom ",
    tmplvertex1: "Modèle de réseau local 1",
    tmplvertex2: "Modèle de réseau local 2",
    tmplvertex_mimetype: "Type",
    tmplvertex_ip1: 'IP / Réseau',
    tmplvertex_ip2: 'IP / Masque',
    tmpledges: "Modèle de tunnel",
    addtmpledge_name: "Nom ",
    // add_node1
    addnode1_select_node_label: "Sélectionner un type de serveur RVP ...",
    addnode1_tmplnode: "Sélectionner un modèle de serveur RVP",
    addnode_name: "Nom ",
    uai: "UAI ",
    addnode1_title: 'Ajouter un nouveau serveur RVP',
    modify_node1_title: 'Modifier le serveur RVP',
    addextremity_title: 'Ajouter une nouvelle IP',
    modextremity_title: 'Modifier',
    addextremity_pub_ip: 'IP publique',
    addextremity_priv_ip: 'IP privée',
    external_ip: 'IP externe',
    send_db: 'Renvoyer sur Zéphir',
    sync_zephir: 'Zéphir infos serveur',
    addnode1_zephir: "Importation Zéphir",
    addnode1_manually: "Création manuelle",
    reload_tmplvertex: 'Recharger valeurs du modèle',

    // zephir
    zephir: 'Zéphir',
    zephir_etab_libelle: 'Nom ',
    zephir_etab_uai: 'UAI ',
    id_zephir: 'Identifiant Zéphir',
    eole_version: 'Version Eole',

    // add_node2
    addnode2_title: 'Ajouter un lien sécurisé vers',
    addnode2_tmplconnect: 'Choisir un modèle de lien sécurisé',
    addnode2_node: 'Choisir un serveur RVP',
    addnode2_choice_button: 'Ajouter',
    modnode2_choice_button: 'Modifier',
    addnode2_cred: 'Certificat',
    addnode2_extr: 'IP',
    addnode2_ask: 'Veuillez indiquer un nom de certificat',
    addnode2_ask_title: 'Nom ',
    extrip_title: 'IP externe',
    extrip_header: 'IP',
    //tmplvertex
    tmplvertex_title: 'Modèle de réseau',

    activate: '',
    // credentials
    cred_title: 'Certificats',
    addcred_title: 'Ajouter un nouveau certificat',
    modcred_title: 'Remplacer certificat',
    cred: 'Certificats',
    cred_header: 'Certificats',
    ca: 'AC',
    cacert: 'Autorité de Certification',
    related_node: 'Serveur RVP associé',
    issuer: 'AC émettrice',
    exp_date_title: "Date d'expiration",
    delta: 'Expire dans (j)',
    addcred_private_key: 'Clef privée',
    addcred_public_key: 'Certificat',
    addcred_passwd: 'Passphrase',
    addcred_name: 'Nom ',
    generated_new_cred: 'Générer un nouveau certificat',
    imported_old_cred: 'Importer un certificat',
    imported_pkcs12_cred: 'Importer un fichier PKCS12',
    cred_request: 'Générer une requête de certificat pour une AC',
    autosign_cred: 'Certificat auto-signé',
    passwd: 'Choisir un mot de passe',
    passwd2: 'Confirmer le mot de passe',
    addcred_pkcs12: 'Fichier PKCS12',
    addcred_pkcs12_passwd: 'Mot de passe PKCS12',
    unmatched_passwd: 'Les mots de passe sont différents',
    //
    selectfile_upload: 'Sélectionner un fichier',
    selectcredential_label: 'Sélectionner un certificat pour ',

    certif_state: 'État',

    //tmplconnect
    addtmpl_connect_credauth: 'Sélectionner une autorité de certification',
    addtmpl_connect_name: 'Nom ',
    //vertex
    vertex_added: 'Réseau local ajouté',
    addvertex_name: 'Nom ',
    vertex_mimetype: 'Type',
    vertex_mimetype_ip: 'IP',
    vertex_mimetype_network: 'Réseau',
    vertex_mimetype_range: 'Plage',
    addvertex_ip_ip1: 'Adresse IP',
    addvertex_range_ip1: 'Adresse IP de début',
    addvertex_range_ip2: 'Adresse IP de fin',
    addvertex_network_ip1: 'Adresse réseau',
    addvertex_network_ip2: 'Adresse de masque',
    vertex_zephir_module: 'Module Zéphir',

    //leftsendcert
    leftsendcert: 'Envoi certificat',
    leftsendcert_always: 'Certificat envoyé TOUJOURS via le protocole ipsec',
    leftsendcert_never: 'Certificat envoyé JAMAIS via le protocol ipsec',
    leftsendcert_always2: 'TOUJOURS via le protocole ipsec',
    leftsendcert_never2: 'JAMAIS via le protocole ipsec',


    error_get_tmplnode: "Ne peut sélectionner d'établissement avec un type 'établissement'",

}

Ext.i18n.python = {
    'Node modified': 'Serveur RVP modifié',
    'TmplConnect added': 'Modèle de lien sécurisé ajouté',
    'TmplNode added': 'Modèle de serveur RVP ajouté',
    'Node deleted': 'Serveur RVP supprimé',
    'Edge deleted': 'Tunnel supprimé',
    'Edge and connect deleted': 'Tunnel et lien sécurisé supprimés',
    'Node is already used by a Connect, you cannot delete it': 'Serveur RVP déjà utilisé par un lien sécurisé, ne peut être supprimé',
    'Name should be unique': 'Le nom doit être unique',
    'Public IP should be unique': "L'adresse IP publique doit être unique",
    'error while saving database': "Erreur à l'enregistrement de la base de donnée",
    'Wrong node for this TmplVertex': 'Mauvais serveur RVP pour ce modèle de réseau local',
    'TmplEdge already exists': 'Ce modèle de tunnel existe déjà',
    'error in add_node: serveur name already in database': 'Le nom du serveur doit être unique',
    'No available connect': 'Pas de lien sécurisé dans la base',
    'Credential imported': 'Certificat importé',
    "Not same subject as old one's": "Subject différent de l'ancien",
    'Unable to decrypt private key, check password': 'Impossible de déchiffrer la clé privée, vérifier passphrase',
    'This TmplEdge is already used, cannot modify tmpl_vertex': 'Ce modèle de tunnel est déjà utilisé, ne peut modifier son modèle de réseau local',
    'Please enter a valid IP address (a.b.c.d)': 'Veuillez entrer une IP valide (a.b.c.d)',
    'Extremity is already used by a Connect, you cannot delete it': 'IP externe déjà utilisée dans un lien sécurisé, ne peut être supprimée',
    'Credential is already used by a Connect, you cannot delete it': 'Certificat utilisé dans un lien sécurisé, ne peut être supprimé',
    'Extemity deleted': 'IP externe supprimée',
    "CA does not exists in database, Can't add certificate": "L'AC n'existe pas dans la base, ne peut ajouter le certificat",
    "Unknown certificate type": "Type de certificat inconnu",
    "Error in execution 'openssl pkcs7' command": "Erreur d'exécution de la commande 'openssl pkcs7'",
    "No CA certificate added": "Aucun certificat AC ajouté",
    "TmplVertex is already used by a TmplEdge, you cannot delete it": "Ce modèle de réseau local est déjà utilisé par un modèle de tunnel, ne peut être supprimé",
    "New credential is issued with another CA than old one's": "Le nouveau certificat est créé à partir d'une autre AC que l'ancien",
    "Credential and private_key doesn't match": "Le certificat et la clef privée ne correspondent pas",
    "Error: unable to find VPN archive": "Erreur : impossible de trouver l'archive RVP",
    "Resended": "Archive envoyée",
    "Database created": "Bases de données créées",
    "Database created - !!! HighAvail synchro : remote node unreachable !!!": "Bases de données créées - !!! Synchronisation haute disponibilité : noeud distant injoignable !!!",
    "Configuration created": "Configurations strongSwan générées",
    "Configuration created - !!! HighAvail synchro : remote node unreachable !!!": "Configurations strongSwan générées - !!! Synchronisation haute disponibilité : noeud distant injoignable !!!",
    "Expiration date": "Date d'expiration",
    "TmplConnect is already used by a Connect, you cannot delete it": "Le modèle de lien est utilisé, suppression impossible",
    "Range network not supported": "Réseau de type Range non supporté",
    "Can't suppress edge template used by connect !!!": "Impossible de supprimer un modèle de tunnel utilisé par un lien sécurisé !!!",
}
